/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import java.util.List;

/**
 * Data class for defining tutorials.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public final class TutorialDefinition {
	/** The hidden composite step for the first level of tutorial steps. */
	private final TutorialStepComposite hiddenCompositeStep;

	/** Constructor. */
	public TutorialDefinition(String title, TutorialStepBase initialStep) {
		this.hiddenCompositeStep = new TutorialStepComposite(title, initialStep);
	}

	/** Returns tutorial steps. MUST NOT return <code>null</code> or an empty list. */
	public List<TutorialStepBase> getSteps() {
		return hiddenCompositeStep.getSteps();
	}

	/** Adds the given tutorial step to the list of steps. */
	public void addStep(TutorialStepBase step) {
		hiddenCompositeStep.addStep(step);
	}

	/** Returns the title of the tutorial. */
	public String getTitle() {
		return hiddenCompositeStep.getTitle();
	}
}
